"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SerialPort = require("serialport");
const helpers_1 = require("../helpers");
const chalk = require("chalk");
const SerialPortDelimiter = require("@serialport/parser-delimiter");
const PACKET_DELIMITER = Buffer.from([0x0a]);
const PACKET_MAGIC = Buffer.from([0xe7, 0x4d, 0x50, 0x4b, 0x54]);
function encodePacket(payload) {
    // Escape sequences.
    payload = helpers_1.bufferReplace(payload, Buffer.from([0xee]), Buffer.from([0xee, 0xe1]));
    payload = helpers_1.bufferReplace(payload, Buffer.from([0x0a]), Buffer.from([0xee, 0xe0]));
    const delimiter = Buffer.from([0x0a]);
    return Buffer.concat([delimiter, PACKET_MAGIC, payload, delimiter]);
}
function decodePacket(packet) {
    const magic = packet.slice(0, PACKET_MAGIC.length);
    if (!magic.equals(PACKET_MAGIC)) {
        throw new Error(`invalid magic (${magic})`);
    }
    let payload = packet.slice(PACKET_MAGIC.length);
    payload = helpers_1.bufferReplace(payload, Buffer.from([0xee, 0xe0]), Buffer.from([0x0a]));
    payload = helpers_1.bufferReplace(payload, Buffer.from([0xee, 0xe1]), Buffer.from([0xee]));
    return payload;
}
class SerialAdapter {
    open(port, baudRate, onRecv) {
        return new Promise((resolve, reject) => {
            this.serial = new SerialPort(port, { baudRate });
            this.serial.on("error", reject);
            this.serial.on("open", () => {
                const serialLines = this.serial.pipe(new SerialPortDelimiter({ delimiter: PACKET_DELIMITER }));
                serialLines.on("data", (line) => {
                    if (line.slice(0, PACKET_MAGIC.length).equals(PACKET_MAGIC)) {
                        onRecv(decodePacket(line));
                    }
                    else {
                        // Log message.
                        console.log(chalk.magenta(`> ${line.toString("ascii").trim()}`));
                    }
                });
                resolve();
            });
        });
    }
    send(payload) {
        this.serial.write(encodePacket(payload));
    }
}
exports.SerialAdapter = SerialAdapter;
//# sourceMappingURL=serial_adapter.js.map