export declare type Validator = RegExp | number | ((arg: string) => any);
export interface ArgDefinition {
    name: string;
    desc: string;
    validator?: Validator;
    default?: any;
}
export interface OptDefinition {
    name: string;
    desc: string;
    validator?: Validator;
    default?: any;
    required?: boolean;
}
export interface Args {
    [name: string]: any;
}
export interface Opts {
    [name: string]: any;
}
export declare abstract class Command {
    static command: string;
    static desc: string;
    static args: ArgDefinition[];
    static opts: OptDefinition[];
    static watchMode: boolean;
    abstract run(args: Args, opts: Opts): Promise<void>;
}
export declare const validateAppDir: Validator;
export declare const validateBoardType: Validator;
export declare const validateCloudType: Validator;
export declare const validateDeviceFilePath: Validator;
export declare const APP_OPTS: {
    name: string;
    desc: string;
    default: string;
    validator: (arg: string) => any;
}[];
export declare const ADAPTER_OPTS: {
    name: string;
    desc: string;
    default: string;
}[];
export declare const BOARD_OPTS: {
    name: string;
    desc: string;
    default: string;
    validator: (arg: string) => any;
}[];
export declare const DEVICE_FILE_OPTS: ({
    name: string;
    desc: string;
    default: string;
    validator: (arg: string) => any;
} | {
    name: string;
    desc: string;
    default: number;
    validator?: undefined;
})[];
export declare const BUILD_OPTS: ({
    name: string;
    desc: string;
    default: string;
} | {
    name: string;
    desc: string;
    default: number;
})[];
export declare const WATCH_OPTS: {
    name: string;
    desc: string;
    default: boolean;
}[];
export declare const CLOUD_OPTS: ({
    name: string;
    desc: string;
    default: string;
    validator: (arg: string) => any;
} | {
    name: string;
    desc: string;
    default?: undefined;
    validator?: undefined;
})[];
