"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("./command");
const firmware_1 = require("../firmware");
const logger_1 = require("../logger");
class FlashCommand extends command_1.Command {
    async run(_args, opts) {
        if (opts.adapter == "wifi") {
            if (!opts.wifiSsid) {
                logger_1.logger.error("The --wifi-ssid option is required.");
            }
            opts.wifiPassword = opts.wifiPassword || process.env.WIFI_PASSWORD;
            if (!opts.wifiPassword) {
                logger_1.logger.error("The --wifi-password is required.");
            }
            if (!opts.serverUrl) {
                logger_1.logger.error("The --server-url is required.");
            }
        }
        logger_1.logger.progress("Flashing...");
        const appCxx = firmware_1.transpileApp(opts.appDir);
        await opts.board.flashFirmware(opts.appDir, appCxx, opts.device, opts);
        logger_1.logger.success("Done!");
    }
}
FlashCommand.command = "flash";
FlashCommand.desc = "Install the firmware on a connected device.";
FlashCommand.args = [];
FlashCommand.opts = [
    ...command_1.BUILD_OPTS,
    ...command_1.DEVICE_FILE_OPTS,
    {
        name: "--wifi-ssid <ssid>",
        desc: "The Wi-Fi SSID.",
    },
    {
        name: "--wifi-password <password>",
        desc: "The Wi-Fi password (you can set this value by $WIFI_PASSWORD environment value instead).",
        default: "",
    },
    {
        name: "--server-url <url>",
        desc: "The server URL. (e.g., https://us-somewhere1-XXXXX.cloudfunctions.net for firebase)." +
            `We strongly recommend to use HTTPS (i.e., URLs starting with "https://") if possible.`
    }
];
exports.FlashCommand = FlashCommand;
//# sourceMappingURL=flash_command.js.map