"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("./command");
const SerialPort = require("serialport");
const SerialPortDelimiter = require("@serialport/parser-delimiter");
function printLines(device, baudRate) {
    return new Promise((resolve, reject) => {
        const serial = new SerialPort(device, { baudRate });
        serial.on("error", reject);
        serial.on("open", () => {
            const delimiter = Buffer.from([0x0a]);
            const serialLines = serial.pipe(new SerialPortDelimiter({ delimiter }));
            serialLines.on("data", (line) => {
                console.log(line.toString("ascii").replace(/\r?\n$/, ""));
            });
            resolve();
        });
    });
}
class SerialCommand extends command_1.Command {
    async run(args, opts) {
        await printLines(opts.device, opts.baudrate);
    }
}
SerialCommand.command = "serial";
SerialCommand.desc = "Read device log messages from the serial port.";
SerialCommand.args = [];
SerialCommand.opts = [
    ...command_1.DEVICE_FILE_OPTS,
];
exports.SerialCommand = SerialCommand;
//# sourceMappingURL=serial_command.js.map