"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const transpiler_1 = require("./transpiler");
const helpers_1 = require("./helpers");
function extractCredentials(path) {
    const image = fs.readFileSync(path);
    const CRED_HEADER_START = "__MAKESTACK_CRED_START__";
    const start = image.indexOf(CRED_HEADER_START);
    if (start < -1) {
        throw new Error("failed to locate the credential");
    }
    const cred = image.slice(start + CRED_HEADER_START.length);
    const version = cred.readUInt32LE(0);
    return { version };
}
exports.extractCredentials = extractCredentials;
const APP_CXX_TEMPLATE = `\
#include <makestack/vm.h>
#include <makestack/logger.h>

{{ code }}
`;
function transpileApp(appDir) {
    const appFile = path.join(appDir, "app.js");
    const appJs = fs.readFileSync(appFile, "utf-8");
    const transpiler = new transpiler_1.Transpiler();
    const code = transpiler.transpile(appJs);
    return helpers_1.render(APP_CXX_TEMPLATE, { code });
}
exports.transpileApp = transpileApp;
async function buildApp(board, appDir, opts) {
    helpers_1.execScriptHook(appDir, "build");
    await board.buildFirmware(appDir, transpileApp(appDir), opts);
}
exports.buildApp = buildApp;
//# sourceMappingURL=firmware.js.map