"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const tmp = require("tmp");
const nunjucks = require("nunjucks");
const child_process_1 = require("child_process");
const logger_1 = require("./logger");
function resolveRepoPath(relpath) {
    return path.join(__dirname, "..", relpath);
}
exports.resolveRepoPath = resolveRepoPath;
function bufferReplace(buf, from, to) {
    let current = 0;
    for (;;) {
        const index = buf.indexOf(from, current);
        if (index < 0) {
            return buf;
        }
        const before = buf.slice(0, index);
        const after = buf.slice(index + from.length);
        // In case to.length < from.length.
        const newLen = index + to.length + after.length;
        buf = Buffer.concat([before, to, after], newLen);
        current = index + to.length;
    }
}
exports.bufferReplace = bufferReplace;
function exec(argv, options = {}) {
    const exe = argv[0];
    const args = argv.slice(1);
    const r = child_process_1.spawnSync(exe, args, Object.assign({}, {
        stdio: "inherit",
        env: process.env,
        encoding: "utf-8",
    }, options));
    if (r.status !== 0) {
        throw new Error(`${exe} exited with ${r.status}`);
    }
}
exports.exec = exec;
function bytesToReadableString(bytes) {
    let base = bytes;
    let i = 0;
    const units = [" bytes", "KB", "MB", "GB"];
    while (base >= 1024 && i < units.length) {
        base /= 1024;
        i++;
    }
    return base.toFixed(2) + units[i];
}
exports.bytesToReadableString = bytesToReadableString;
function render(template, ctx) {
    nunjucks.configure({ autoescape: false });
    return nunjucks.renderString(template, ctx);
}
exports.render = render;
function createTmpDir(prefix) {
    return tmp.dirSync({ prefix }).name;
}
exports.createTmpDir = createTmpDir;
function execScriptHook(appDir, hook) {
    const scripts = fs.readJSONSync(path.join(appDir, "package.json")).scripts;
    if (scripts && scripts[hook]) {
        logger_1.logger.progress(`Running ${hook} hook`);
        logger_1.logger.command(scripts[hook]);
        exec(["sh", "-c", scripts[hook]], { cwd: appDir });
    }
}
exports.execScriptHook = execScriptHook;
//# sourceMappingURL=helpers.js.map