"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const { green, blue, red, cyanBright, magenta, bold } = require("chalk");
function join(messages) {
    return messages.map((m) => m.toString()).join(" ");
}
class Logger {
    constructor(subject) {
        this.subject = subject;
        this.stdout = true;
        this.buffer = "";
    }
    _log(str, forceStdout) {
        if (forceStdout || this.stdout) {
            console.log(str);
        }
        else {
            this.buffer += str;
        }
    }
    log(str, forceStdout = false) {
        if (this.subject) {
            const colors = {
                server: blue,
                device: magenta,
            };
            const prefix = colors[this.subject](this.subject.padStart(8) + ":");
            this._log(prefix + " " + str, forceStdout);
        }
        else {
            this._log(str, forceStdout);
        }
    }
    enableStdout() {
        this.stdout = true;
        const buffer = this.buffer;
        this.buffer = "";
        return buffer;
    }
    disableStdout() {
        //        this.stdout = false;
    }
    debug(...messages) {
        this.log(join(messages));
    }
    info(...messages) {
        this.log(cyanBright(join(messages)));
    }
    warn(...messages) {
        this.log(red.yellow(join(messages)));
    }
    error(...messages) {
        this.log(red.bold("Error: " + join(messages)), true);
        process.exit(1);
    }
    command(...messages) {
        const maxLen = process.stdout.columns || 80;
        const str = join(messages);
        let truncated;
        if (str.length > maxLen) {
            truncated = str.slice(0, maxLen - 3) + "...";
        }
        else {
            truncated = str;
        }
        this.log(bold(truncated));
    }
    success(...messages) {
        this.log(bold(green("==> ") + join(messages)));
    }
    failure(...messages) {
        this.log(bold(red("==> ") + join(messages)));
    }
    progress(...messages) {
        this.log(bold(blue("==> ") + join(messages)));
    }
    action(action, target) {
        this.log(magenta.bold(action.padStart(8)) + "  " + target);
    }
}
exports.Logger = Logger;
exports.logger = new Logger();
//# sourceMappingURL=logger.js.map