"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const caporal = require("caporal");
const fs = require("fs");
const path = require("path");
const commands_1 = require("./commands");
const logger_1 = require("./logger");
const command_1 = require("./commands/command");
const { version } = require(path.resolve(__dirname, "../package.json"));
caporal.description("A minimalistic IoT framework for super-rapid prototyping.");
caporal.version(version);
// Load commands.
for (const klass of commands_1.commands) {
    const cmd = caporal.command(klass.command, klass.desc);
    for (const arg of klass.args) {
        cmd.argument(arg.name, arg.desc, arg.validator, arg.default);
    }
    let opts = klass.opts;
    if (klass.watchMode) {
        opts = [...opts, ...command_1.WATCH_OPTS];
    }
    let addedOpts = [];
    for (const opt of opts) {
        if (!addedOpts.includes(opt.name)) {
            cmd.option(opt.name, opt.desc, opt.validator, opt.default, opt.required);
        }
        addedOpts.push(opt.name);
    }
    cmd.action(async (args, opts) => {
        const instance = new klass();
        try {
            await instance.run(args, opts);
            if (opts.watch) {
                logger_1.logger.info("Watching app.js for changes...");
                fs.watchFile(path.join(opts.appDir, "app.js"), () => {
                    instance.run(args, opts);
                });
            }
        }
        catch (e) {
            logger_1.logger.error(e.stack);
            process.exit(1);
        }
    });
}
function run(args) {
    const argv = args ? [process.argv0, "makestack", ...args] : process.argv;
    return caporal.parse(argv);
}
exports.run = run;
//# sourceMappingURL=main.js.map