"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const readline = require("readline");
const PATTERNS = ["-", "\\", "|", "/"];
class Spinner {
    constructor() {
        this.count = 0;
    }
    start() {
        if (process.env.DISABLE_SPINNER) {
            return;
        }
        this.timer = setInterval(() => {
            this.count++;
            this.render();
        }, 70);
    }
    update(message) {
        if (process.env.DISABLE_SPINNER) {
            console.log(message);
            return;
        }
        const maxLen = (process.stdout.columns || 80) - 2;
        const truncated = message.slice(0, maxLen);
        this.message = truncated;
        this.render();
    }
    reset() {
        if (this.timer) {
            this.count = 0;
            clearInterval(this.timer);
            readline.clearLine(process.stdout, 0);
            readline.cursorTo(process.stdout, 0);
        }
    }
    render() {
        if (this.message) {
            const spin = PATTERNS[this.count % PATTERNS.length] + " ";
            readline.clearLine(process.stdout, 0);
            readline.cursorTo(process.stdout, 0);
            process.stdout.write(spin + this.message);
        }
    }
}
exports.Spinner = Spinner;
//# sourceMappingURL=spinner.js.map